#include "stdio.h"
#include "stdlib.h"
#include "io.h"
#include "alt_types.h"


/**********************************************************************************
 * This function is responsible for allocating input and output data buffers.     *
 * A random buffer length will be generated if minimum and maximum buffer lengths *
 * are different.                                                                 *
 *                                                                                *
 * Returns 0 for success, 1 for failure.                                          *
 **********************************************************************************/
alt_u32 create_test_data(alt_8  *** input_buffers_p,
                         alt_16 *** output_buffers_p,
                         alt_u16 ** buffer_lengths_p,
                         alt_u16 number_of_buffers,
                         alt_u16 minimum_buffer_length,
                         alt_u16 maximum_buffer_length)
{

  alt_u32 buffer_counter, contents_counter, temp_length;
  alt_u32 temp_data = 0;

  alt_8  ** input_buffers  = (alt_8  **) malloc(number_of_buffers * sizeof(alt_8 *));
  alt_16 ** output_buffers = (alt_16 **) malloc(number_of_buffers * sizeof(alt_16 *));
  alt_u16 * buffer_lengths = (alt_u16 *) malloc(number_of_buffers * sizeof(alt_u16));

  if ((input_buffers == NULL) || (output_buffers == NULL) || (buffer_lengths == NULL))
  {
    printf("Buffer allocation failed\n");
    return 1;
  }

  *input_buffers_p = input_buffers;
  *output_buffers_p = output_buffers;
  *buffer_lengths_p = buffer_lengths;

  /*  Initialisation of the buffer memories and the transmit+receive descriptors */
  for(buffer_counter = 0; buffer_counter < number_of_buffers; buffer_counter++)
  {

	/*  Generate a random buffer length between within MINIMUM_BUFFER_LENGTH and MAXIMUM_BUFFER_LENGTH */
    if(minimum_buffer_length == maximum_buffer_length)  // if you don't want a random length set these equal
    {  
      temp_length = minimum_buffer_length;
    }
    else
    {
      if(minimum_buffer_length > maximum_buffer_length)
      {
         printf("Please set the maximum buffer length to be larger than\n");
         printf("the minimum buffer length (in includes_and_settigns.h)\n");
         return 1;
      }
      temp_length = (rand() % (maximum_buffer_length - minimum_buffer_length)) + minimum_buffer_length;      
    }
    
    
    buffer_lengths[buffer_counter] = temp_length;

    input_buffers[buffer_counter] = (alt_8 *)malloc(temp_length * sizeof(alt_8));
    if(input_buffers[buffer_counter] == NULL)
    {
      printf("Allocating a transmit buffer region failed\n");
      return 1; 
    }
    output_buffers[buffer_counter] = (alt_16 *)malloc(temp_length * sizeof(alt_16));
    if(output_buffers[buffer_counter] == NULL)
    {
      printf("Allocating a receive buffer region failed\n");
      return 1; 
    }

    /* This will populate sequential data (modulo 256) in each transmit buffer a byte at a time.
     * The receive buffers are also cleared with zeros so that each time this software is run
     * the data can be reverified.
     */

    for(contents_counter = 0; contents_counter < temp_length; contents_counter++)
    {
      input_buffers[buffer_counter][contents_counter] = (alt_8)(temp_data & 0xFF);
      output_buffers[buffer_counter][contents_counter] = 0;
      temp_data++;
    }

  }
  
  return 0;  // no failures creating data buffers
}
