###############################################################################
# pin_assignment_DE1_SoC.tcl
# ==========================
#
# BOARD : DE1-SoC from Terasic
# Author : Sahand Kashani-Akhavan from Terasic documentation
# Revision : 1.7
# Last updated : 2017-06-09 19:29:39 UTC
#
# Syntax Rule : GROUP_NAME_N[bit]
#
# GROUP  : specify a particular interface (ex: SDR_)
# NAME   : signal name (ex: CONFIG, D, ...)
# bit    : signal index
# _N     : to specify an active-low signal
#
# You can run this script from Quartus by observing the following steps:
# 1. Place this TCL script in your project directory
# 2. Open your project in Quartus
# 3. Go to the View > Utility Windows -> Tcl Console
# 4. In the Tcl Console type:
#        source pin_assignment_DE1_SoC.tcl
#
# 5. The script will assign pins and return an "assignment made" message.
###############################################################################

set_global_assignment -name FAMILY "Cyclone V"
set_global_assignment -name DEVICE 5CSEMA5F31C6
set_global_assignment -name DEVICE_FILTER_PACKAGE FBGA
set_global_assignment -name DEVICE_FILTER_PIN_COUNT 896
set_global_assignment -name DEVICE_FILTER_SPEED_GRADE 6

#============================================================
# CLOCK
#============================================================
set_location_assignment PIN_AF14 -to clk_50MHz
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to clk_50MHz

#============================================================
# SDRAM
#============================================================
set_location_assignment PIN_AK14 -to SDRAM_ADDR[0]
set_location_assignment PIN_AH14 -to SDRAM_ADDR[1]
set_location_assignment PIN_AG15 -to SDRAM_ADDR[2]
set_location_assignment PIN_AE14 -to SDRAM_ADDR[3]
set_location_assignment PIN_AB15 -to SDRAM_ADDR[4]
set_location_assignment PIN_AC14 -to SDRAM_ADDR[5]
set_location_assignment PIN_AD14 -to SDRAM_ADDR[6]
set_location_assignment PIN_AF15 -to SDRAM_ADDR[7]
set_location_assignment PIN_AH15 -to SDRAM_ADDR[8]
set_location_assignment PIN_AG13 -to SDRAM_ADDR[9]
set_location_assignment PIN_AG12 -to SDRAM_ADDR[10]
set_location_assignment PIN_AH13 -to SDRAM_ADDR[11]
set_location_assignment PIN_AJ14 -to SDRAM_ADDR[12]
set_location_assignment PIN_AF13 -to SDRAM_BA[0]
set_location_assignment PIN_AJ12 -to SDRAM_BA[1]
set_location_assignment PIN_AF11 -to SDRAM_CAS_N
set_location_assignment PIN_AK13 -to SDRAM_CKE
set_location_assignment PIN_AG11 -to SDRAM_CS_N
set_location_assignment PIN_AH12 -to SDRAM_CLK
set_location_assignment PIN_AK6  -to SDRAM_DQ[0]
set_location_assignment PIN_AJ7  -to SDRAM_DQ[1]
set_location_assignment PIN_AK7  -to SDRAM_DQ[2]
set_location_assignment PIN_AK8  -to SDRAM_DQ[3]
set_location_assignment PIN_AK9  -to SDRAM_DQ[4]
set_location_assignment PIN_AG10 -to SDRAM_DQ[5]
set_location_assignment PIN_AK11 -to SDRAM_DQ[6]
set_location_assignment PIN_AJ11 -to SDRAM_DQ[7]
set_location_assignment PIN_AH10 -to SDRAM_DQ[8]
set_location_assignment PIN_AJ10 -to SDRAM_DQ[9]
set_location_assignment PIN_AJ9  -to SDRAM_DQ[10]
set_location_assignment PIN_AH9  -to SDRAM_DQ[11]
set_location_assignment PIN_AH8  -to SDRAM_DQ[12]
set_location_assignment PIN_AH7  -to SDRAM_DQ[13]
set_location_assignment PIN_AJ6  -to SDRAM_DQ[14]
set_location_assignment PIN_AJ5  -to SDRAM_DQ[15]
set_location_assignment PIN_AB13 -to SDRAM_DQM[0]
set_location_assignment PIN_AE13 -to SDRAM_RAS_N
set_location_assignment PIN_AK12 -to SDRAM_DQM[1]
set_location_assignment PIN_AA13 -to SDRAM_WE_N

set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[0]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[1]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[2]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[3]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[4]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[5]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[6]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[7]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[8]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[9]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[10]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[11]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_ADDR[12]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_BA[0]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_BA[1]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_CAS_N
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_CKE
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_CS_N
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_CLK
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[0]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[1]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[2]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[3]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[4]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[5]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[6]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[7]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[8]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[9]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[10]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[11]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[12]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[13]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[14]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQ[15]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQM[0]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_RAS_N
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_DQM[1]
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to SDRAM_WE_N


#============================================================
# SW
#============================================================
set_location_assignment PIN_AE12 -to reset_n
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to reset_n
